package pps.core.space.service;

import cn.hutool.core.date.DateField;
import cn.hutool.core.date.DateTime;
import cn.hutool.core.date.DateUtil;
import pps.cloud.prediction.service.IThirdActivePowerCloudService;
import pps.cloud.prediction.service.data.third_active_power.GetThirdActivePowerInput;
import pps.cloud.prediction.service.data.third_active_power.GetThirdActivePowerOutput;
import pps.cloud.space.service.IDailyElectricityTrendCloudService;
import pps.core.common.constant.BusinessConstant;
import xstartup.annotation.XService;
import xstartup.base.XContext;
import xstartup.data.XListResult;
import xstartup.data.XServiceResult;

import java.util.List;

/**
 * 日用电趋势计算Cloud模块
 *
 * @author ZWT
 * @date 2024/05/22 17:17
 */
@XService
public class DailyElectricityTrendCloudServiceImpl extends SpaceOptimizeBaseService implements IDailyElectricityTrendCloudService {

    /**
     * 日用电趋势计算
     * <p>
     * (1)取昨日极短期间开优化结果
     * (2)绿电阶段开井时间：每15分钟判段光伏出力>运行功率（考虑开井顺序） 并且当前时段开井，则算坐开井时段(0.25小时)，全天累加
     * (3)单井绿电用电：运行功率*绿电阶段开井时间
     * (4)市电用电:总用电-光伏用电
     *
     * @param context 上下文
     * @return {@link XServiceResult }
     */
    @Override
    public XServiceResult dailyElectricityTrendJob(XContext context) {
        DateTime yesterday = DateUtil.beginOfDay(DateUtil.yesterday());
        IThirdActivePowerCloudService service = context.getBean(IThirdActivePowerCloudService.class);
        XListResult<GetThirdActivePowerOutput> result = service.queryAvgPhotovoltaicPower(context, GetThirdActivePowerInput.builder()
                .createDate(yesterday)
                .build());
        result.throwIfFail();
        List<GetThirdActivePowerOutput> list = result.getResult();

        List<DateTime> rangeToList = DateUtil.rangeToList(BusinessConstant.DATE_FLAG_BEGIN, BusinessConstant.DATE_FLAG, DateField.MINUTE, 15);
        return null;
    }
}
