package pps.core.prediction.service;

import pps.cloud.prediction.service.IThirdActivePowerCloudService;
import pps.cloud.prediction.service.data.third_active_power.GetThirdActivePowerInput;
import pps.cloud.prediction.service.data.third_active_power.GetThirdActivePowerOutput;
import pps.core.prediction.entity.ThirdActivePowerView;
import pps.core.prediction.mapper.ThirdActivePowerViewMapper;
import xstartup.annotation.XService;
import xstartup.annotation.XText;
import xstartup.base.XContext;
import xstartup.base.util.XCopyUtils;
import xstartup.data.XListResult;

import java.util.List;

/**
 * 第三方有功功率Cloud模块
 *
 * @author ZWT
 * @date 2024/05/23 14:18
 */
@XText("第三方有功功率Cloud模块")
@XService
public class ThirdActivePowerCloudServiceImpl implements IThirdActivePowerCloudService {

    /**
     * 获得15分钟平均功率
     *
     * @param context 上下文
     * @param input   输入
     * @return {@link XListResult }<{@link GetThirdActivePowerOutput }>
     */
    @Override
    public XListResult<GetThirdActivePowerOutput> queryAvgPhotovoltaicPower(XContext context, GetThirdActivePowerInput input) {
        ThirdActivePowerViewMapper mapper = context.getBean(ThirdActivePowerViewMapper.class);
        List<ThirdActivePowerView> list = mapper.selectAvgPhotovoltaicPower(ThirdActivePowerView.builder()
                .createDate(input.getCreateDate())
                .build());
        return XListResult.success(XCopyUtils.copyNewList(list, GetThirdActivePowerOutput.class));
    }
}
